# coding: utf-8

# flake8: noqa
"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from iblai.models.ai_generated_image import AIGeneratedImage
from iblai.models.ai_user_profile_memory_relation import AIUserProfileMemoryRelation
from iblai.models.ai_user_profile_request import AIUserProfileRequest
from iblai.models.api_token_cost import APITokenCost
from iblai.models.aws_tenant_launch_request import AWSTenantLaunchRequest
from iblai.models.acceptance_enum import AcceptanceEnum
from iblai.models.access_enum import AccessEnum
from iblai.models.activate_user_free_trial import ActivateUserFreeTrial
from iblai.models.active_users_data import ActiveUsersData
from iblai.models.active_users_list import ActiveUsersList
from iblai.models.active_users_per_course import ActiveUsersPerCourse
from iblai.models.active_users_per_course_data import ActiveUsersPerCourseData
from iblai.models.activity_api import ActivityAPI
from iblai.models.activity_data import ActivityData
from iblai.models.ai_account_orgs_use_default_llm_key_create200_response import AiAccountOrgsUseDefaultLlmKeyCreate200Response
from iblai.models.ai_account_orgs_users_free_trial_retrieve200_response import AiAccountOrgsUsersFreeTrialRetrieve200Response
from iblai.models.align_mentor_bubble_enum import AlignMentorBubbleEnum
from iblai.models.analytics_overview import AnalyticsOverview
from iblai.models.answer import Answer
from iblai.models.app import App
from iblai.models.apple_subscription_status_request import AppleSubscriptionStatusRequest
from iblai.models.apple_subscription_status_view import AppleSubscriptionStatusView
from iblai.models.apple_verify_transaction_id import AppleVerifyTransactionId
from iblai.models.assertion import Assertion
from iblai.models.associate_account_response import AssociateAccountResponse
from iblai.models.associate_apple_account import AssociateAppleAccount
from iblai.models.assumed_knowledge import AssumedKnowledge
from iblai.models.assumed_knowledge_level import AssumedKnowledgeLevel
from iblai.models.audio_to_text_request import AudioToTextRequest
from iblai.models.audio_to_text_response import AudioToTextResponse
from iblai.models.auth_token import AuthToken
from iblai.models.average import Average
from iblai.models.average_data import AverageData
from iblai.models.average_overtime import AverageOvertime
from iblai.models.avg_course_grade_with_cutoff import AvgCourseGradeWithCutoff
from iblai.models.avg_course_grade_with_cutoff_data import AvgCourseGradeWithCutoffData
from iblai.models.base_error_response import BaseErrorResponse
from iblai.models.base_response import BaseResponse
from iblai.models.blank_course_invitation_create import BlankCourseInvitationCreate
from iblai.models.blank_enum import BlankEnum
from iblai.models.blank_platform_invitation_create import BlankPlatformInvitationCreate
from iblai.models.blank_program_invitation_create import BlankProgramInvitationCreate
from iblai.models.block_skill_point_info_request import BlockSkillPointInfoRequest
from iblai.models.bot import Bot
from iblai.models.bot_command import BotCommand
from iblai.models.bot_create import BotCreate
from iblai.models.bulk_course_invitation_create import BulkCourseInvitationCreate
from iblai.models.bulk_course_invitation_response import BulkCourseInvitationResponse
from iblai.models.bulk_create_assertion import BulkCreateAssertion
from iblai.models.bulk_platform_invitation_create import BulkPlatformInvitationCreate
from iblai.models.bulk_platform_invitation_response import BulkPlatformInvitationResponse
from iblai.models.bulk_program_invitation_create import BulkProgramInvitationCreate
from iblai.models.bulk_program_invitation_response import BulkProgramInvitationResponse
from iblai.models.bulk_suggestion_response import BulkSuggestionResponse
from iblai.models.call_authentication_request import CallAuthenticationRequest
from iblai.models.call_authentication_response import CallAuthenticationResponse
from iblai.models.call_configuration import CallConfiguration
from iblai.models.call_configuration_mode_enum import CallConfigurationModeEnum
from iblai.models.campaign_enablement import CampaignEnablement
from iblai.models.campaign_exclusion import CampaignExclusion
from iblai.models.catalog_auto_increment_response import CatalogAutoIncrementResponse
from iblai.models.catalog_auto_increment_update_request import CatalogAutoIncrementUpdateRequest
from iblai.models.celery_heartbeat import CeleryHeartbeat
from iblai.models.celery_heartbeat_fail import CeleryHeartbeatFail
from iblai.models.celery_heartbeat_fail_status_enum import CeleryHeartbeatFailStatusEnum
from iblai.models.celery_heartbeat_status_enum import CeleryHeartbeatStatusEnum
from iblai.models.chat_history import ChatHistory
from iblai.models.chat_history_filter_data import ChatHistoryFilterData
from iblai.models.chat_history_filter_user import ChatHistoryFilterUser
from iblai.models.chat_history_item import ChatHistoryItem
from iblai.models.chat_history_session_id import ChatHistorySessionId
from iblai.models.chat_session_request import ChatSessionRequest
from iblai.models.chat_session_response import ChatSessionResponse
from iblai.models.check_document_training_status import CheckDocumentTrainingStatus
from iblai.models.company import Company
from iblai.models.component_block import ComponentBlock
from iblai.models.component_block_type_enum import ComponentBlockTypeEnum
from iblai.models.context_response import ContextResponse
from iblai.models.conversation_message import ConversationMessage
from iblai.models.conversation_rating import ConversationRating
from iblai.models.conversation_summary import ConversationSummary
from iblai.models.conversation_volume import ConversationVolume
from iblai.models.conversations import Conversations
from iblai.models.cost import Cost
from iblai.models.cost_per_tenant import CostPerTenant
from iblai.models.count import Count
from iblai.models.count_data import CountData
from iblai.models.course import Course
from iblai.models.course_access_request_create import CourseAccessRequestCreate
from iblai.models.course_access_request_detail import CourseAccessRequestDetail
from iblai.models.course_access_request_status_response import CourseAccessRequestStatusResponse
from iblai.models.course_access_request_update import CourseAccessRequestUpdate
from iblai.models.course_completion import CourseCompletion
from iblai.models.course_completion_per_course import CourseCompletionPerCourse
from iblai.models.course_completion_per_course_data import CourseCompletionPerCourseData
from iblai.models.course_completion_summary_data_overtime import CourseCompletionSummaryDataOvertime
from iblai.models.course_completion_summary_overtime import CourseCompletionSummaryOvertime
from iblai.models.course_create_update import CourseCreateUpdate
from iblai.models.course_creation_task import CourseCreationTask
from iblai.models.course_creation_task_file import CourseCreationTaskFile
from iblai.models.course_creation_task_status_enum import CourseCreationTaskStatusEnum
from iblai.models.course_delete_response import CourseDeleteResponse
from iblai.models.course_enrollment_search_response import CourseEnrollmentSearchResponse
from iblai.models.course_grade_detail_block import CourseGradeDetailBlock
from iblai.models.course_grade_detail_sub_section import CourseGradeDetailSubSection
from iblai.models.course_grade_summary import CourseGradeSummary
from iblai.models.course_grade_summary_data import CourseGradeSummaryData
from iblai.models.course_grading_detail import CourseGradingDetail
from iblai.models.course_grading_detail_data import CourseGradingDetailData
from iblai.models.course_group_suggestion_create import CourseGroupSuggestionCreate
from iblai.models.course_group_suggestion_detail import CourseGroupSuggestionDetail
from iblai.models.course_invitation_create import CourseInvitationCreate
from iblai.models.course_invitation_detail import CourseInvitationDetail
from iblai.models.course_invitation_redemption import CourseInvitationRedemption
from iblai.models.course_license_assignment_create import CourseLicenseAssignmentCreate
from iblai.models.course_license_assignment_detail import CourseLicenseAssignmentDetail
from iblai.models.course_license_create import CourseLicenseCreate
from iblai.models.course_license_detail import CourseLicenseDetail
from iblai.models.course_license_group_assignment_create import CourseLicenseGroupAssignmentCreate
from iblai.models.course_license_group_assignment_detail import CourseLicenseGroupAssignmentDetail
from iblai.models.course_license_update import CourseLicenseUpdate
from iblai.models.course_metadata_search_request import CourseMetadataSearchRequest
from iblai.models.course_metadata_update_request import CourseMetadataUpdateRequest
from iblai.models.course_point import CoursePoint
from iblai.models.course_review_info_response import CourseReviewInfoResponse
from iblai.models.course_review_paginated_response import CourseReviewPaginatedResponse
from iblai.models.course_review_request import CourseReviewRequest
from iblai.models.course_review_response import CourseReviewResponse
from iblai.models.course_skill import CourseSkill
from iblai.models.course_skill_point_info_request import CourseSkillPointInfoRequest
from iblai.models.course_suggestion_bulk_create import CourseSuggestionBulkCreate
from iblai.models.course_suggestion_create import CourseSuggestionCreate
from iblai.models.course_suggestion_detail import CourseSuggestionDetail
from iblai.models.credential import Credential
from iblai.models.credential_request import CredentialRequest
from iblai.models.crontab_schedule import CrontabSchedule
from iblai.models.custom_instruction_response import CustomInstructionResponse
from iblai.models.data_set import DataSet
from iblai.models.data_set_create import DataSetCreate
from iblai.models.data_set_platform_value import DataSetPlatformValue
from iblai.models.data_set_status_enum import DataSetStatusEnum
from iblai.models.date_range import DateRange
from iblai.models.desired_role import DesiredRole
from iblai.models.desired_role_create_update_request import DesiredRoleCreateUpdateRequest
from iblai.models.desired_skill import DesiredSkill
from iblai.models.desired_skill_create_update_request import DesiredSkillCreateUpdateRequest
from iblai.models.detailed_grade_subsection import DetailedGradeSubsection
from iblai.models.detailed_grade_view import DetailedGradeView
from iblai.models.detailed_grade_view_data import DetailedGradeViewData
from iblai.models.discord_config import DiscordConfig
from iblai.models.discord_user_config import DiscordUserConfig
from iblai.models.discord_webhook import DiscordWebhook
from iblai.models.document import Document
from iblai.models.document_facet import DocumentFacet
from iblai.models.document_search_response import DocumentSearchResponse
from iblai.models.document_settings_response import DocumentSettingsResponse
from iblai.models.education import Education
from iblai.models.edx_course import EdxCourse
from iblai.models.edx_signal_receiver_request import EdxSignalReceiverRequest
from iblai.models.elevenlabs_custom_voice import ElevenlabsCustomVoice
from iblai.models.elevenlabs_custom_voice_response import ElevenlabsCustomVoiceResponse
from iblai.models.email_prompt_detail import EmailPromptDetail
from iblai.models.email_prompt_list import EmailPromptList
from iblai.models.email_prompt_summary import EmailPromptSummary
from iblai.models.engagement_per_course import EngagementPerCourse
from iblai.models.engagement_per_course_data import EngagementPerCourseData
from iblai.models.enrollments import Enrollments
from iblai.models.enrollments_data import EnrollmentsData
from iblai.models.enrollments_per_user import EnrollmentsPerUser
from iblai.models.enrollments_per_user_data import EnrollmentsPerUserData
from iblai.models.error_response import ErrorResponse
from iblai.models.experience import Experience
from iblai.models.float_over_time import FloatOverTime
from iblai.models.free_usage_count import FreeUsageCount
from iblai.models.full_course import FullCourse
from iblai.models.gcp_tenant_launch_request import GCPTenantLaunchRequest
from iblai.models.global_catalog_search_response import GlobalCatalogSearchResponse
from iblai.models.google_pay_account_response import GooglePayAccountResponse
from iblai.models.google_pay_account_response_status_enum import GooglePayAccountResponseStatusEnum
from iblai.models.google_pay_verify_token import GooglePayVerifyToken
from iblai.models.grading_per_user import GradingPerUser
from iblai.models.grading_per_user_data import GradingPerUserData
from iblai.models.greeting_method_enum import GreetingMethodEnum
from iblai.models.group_list import GroupList
from iblai.models.group_list_data import GroupListData
from iblai.models.guided_prompts_response import GuidedPromptsResponse
from iblai.models.heygen_marketing_video_detail import HeygenMarketingVideoDetail
from iblai.models.heygen_marketing_video_list import HeygenMarketingVideoList
from iblai.models.heygen_template_request import HeygenTemplateRequest
from iblai.models.heygen_template_response_single import HeygenTemplateResponseSingle
from iblai.models.heygen_video_detail import HeygenVideoDetail
from iblai.models.heygen_video_request import HeygenVideoRequest
from iblai.models.iblai_platform_meta import IBLAIPlatformMeta
from iblai.models.iblai_platform_meta_request import IBLAIPlatformMetaRequest
from iblai.models.iblai_platform_meta_update_request import IBLAIPlatformMetaUpdateRequest
from iblai.models.image_upload import ImageUpload
from iblai.models.input_question import InputQuestion
from iblai.models.institution import Institution
from iblai.models.institution_type_enum import InstitutionTypeEnum
from iblai.models.integration_credential import IntegrationCredential
from iblai.models.intial_question_answer import IntialQuestionAnswer
from iblai.models.issuer import Issuer
from iblai.models.issuer_authority import IssuerAuthority
from iblai.models.item_type_enum import ItemTypeEnum
from iblai.models.job_run import JobRun
from iblai.models.kind_enum import KindEnum
from iblai.models.llm_credential_request import LLMCredentialRequest
from iblai.models.llm_credential_response import LLMCredentialResponse
from iblai.models.llm_model_for_tenant import LLMModelForTenant
from iblai.models.llm_question import LLMQuestion
from iblai.models.llm_response import LLMResponse
from iblai.models.llm_traces_list_response import LLMTracesListResponse
from iblai.models.languages_view import LanguagesView
from iblai.models.launcher_view_post_request import LauncherViewPostRequest
from iblai.models.learner_information_api import LearnerInformationAPI
from iblai.models.learner_information_api_data import LearnerInformationAPIData
from iblai.models.link_course_request import LinkCourseRequest
from iblai.models.link_course_response import LinkCourseResponse
from iblai.models.llm_provider_enum import LlmProviderEnum
from iblai.models.lti_key import LtiKey
from iblai.models.lti_launch_gate import LtiLaunchGate
from iblai.models.lti_tool import LtiTool
from iblai.models.mcp_server import MCPServer
from iblai.models.manager_auth_token import ManagerAuthToken
from iblai.models.mark_all_read_request import MarkAllReadRequest
from iblai.models.mark_all_read_response import MarkAllReadResponse
from iblai.models.media_resource import MediaResource
from iblai.models.media_type_enum import MediaTypeEnum
from iblai.models.memory_component_data import MemoryComponentData
from iblai.models.memory_component_memory import MemoryComponentMemory
from iblai.models.memory_component_memory_detail import MemoryComponentMemoryDetail
from iblai.models.memory_component_response import MemoryComponentResponse
from iblai.models.memory_progress import MemoryProgress
from iblai.models.memory_status_request_view import MemoryStatusRequestView
from iblai.models.memory_status_view import MemoryStatusView
from iblai.models.mentor import Mentor
from iblai.models.mentor_audience import MentorAudience
from iblai.models.mentor_category import MentorCategory
from iblai.models.mentor_category_create import MentorCategoryCreate
from iblai.models.mentor_category_group import MentorCategoryGroup
from iblai.models.mentor_category_group_create import MentorCategoryGroupCreate
from iblai.models.mentor_create import MentorCreate
from iblai.models.mentor_custom_voice import MentorCustomVoice
from iblai.models.mentor_custom_voice_response import MentorCustomVoiceResponse
from iblai.models.mentor_data import MentorData
from iblai.models.mentor_detail_analytics import MentorDetailAnalytics
from iblai.models.mentor_eval import MentorEval
from iblai.models.mentor_eval_question import MentorEvalQuestion
from iblai.models.mentor_eval_question_request import MentorEvalQuestionRequest
from iblai.models.mentor_eval_report import MentorEvalReport
from iblai.models.mentor_eval_request import MentorEvalRequest
from iblai.models.mentor_facet import MentorFacet
from iblai.models.mentor_fork import MentorFork
from iblai.models.mentor_from_template_request import MentorFromTemplateRequest
from iblai.models.mentor_from_template_with_setting_request import MentorFromTemplateWithSettingRequest
from iblai.models.mentor_memory_settings_request import MentorMemorySettingsRequest
from iblai.models.mentor_memory_settings_response import MentorMemorySettingsResponse
from iblai.models.mentor_metadata import MentorMetadata
from iblai.models.mentor_scenario import MentorScenario
from iblai.models.mentor_scenario_prompt import MentorScenarioPrompt
from iblai.models.mentor_search_response import MentorSearchResponse
from iblai.models.mentor_session import MentorSession
from iblai.models.mentor_settings import MentorSettings
from iblai.models.mentor_settings_mentor_visibility import MentorSettingsMentorVisibility
from iblai.models.mentor_settings_public import MentorSettingsPublic
from iblai.models.mentor_settings_request import MentorSettingsRequest
from iblai.models.mentor_visibility_enum import MentorVisibilityEnum
from iblai.models.mentor_wizard import MentorWizard
from iblai.models.message_statistics import MessageStatistics
from iblai.models.message_status import MessageStatus
from iblai.models.message_view import MessageView
from iblai.models.message_view_request import MessageViewRequest
from iblai.models.message_view_updat_response import MessageViewUpdatResponse
from iblai.models.metadata import Metadata
from iblai.models.metric_change import MetricChange
from iblai.models.model_cost import ModelCost
from iblai.models.moderation_log import ModerationLog
from iblai.models.net_revenue_over_time import NetRevenueOverTime
from iblai.models.new_per_learner_list import NewPerLearnerList
from iblai.models.new_per_learner_list_data import NewPerLearnerListData
from iblai.models.no_chat_messages_found import NoChatMessagesFound
from iblai.models.notification import Notification
from iblai.models.notification_count import NotificationCount
from iblai.models.notification_preview import NotificationPreview
from iblai.models.notification_source import NotificationSource
from iblai.models.notification_source_type_enum import NotificationSourceTypeEnum
from iblai.models.notification_status_enum import NotificationStatusEnum
from iblai.models.notification_template_data import NotificationTemplateData
from iblai.models.notification_v1_campaigns_unsubscribe_retrieve200_response import NotificationV1CampaignsUnsubscribeRetrieve200Response
from iblai.models.null_enum import NullEnum
from iblai.models.onboarding_status_update import OnboardingStatusUpdate
from iblai.models.order import Order
from iblai.models.over_time import OverTime
from iblai.models.over_time_with_total import OverTimeWithTotal
from iblai.models.overtime_meta import OvertimeMeta
from iblai.models.overtime_with_change_info import OvertimeWithChangeInfo
from iblai.models.page_content import PageContent
from iblai.models.paginated_ai_generated_image_list import PaginatedAIGeneratedImageList
from iblai.models.paginated_assertions_response import PaginatedAssertionsResponse
from iblai.models.paginated_conversations_list import PaginatedConversationsList
from iblai.models.paginated_course_access_request import PaginatedCourseAccessRequest
from iblai.models.paginated_course_creation_task_file_list import PaginatedCourseCreationTaskFileList
from iblai.models.paginated_course_creation_task_list import PaginatedCourseCreationTaskList
from iblai.models.paginated_course_group_suggestion import PaginatedCourseGroupSuggestion
from iblai.models.paginated_course_invitation import PaginatedCourseInvitation
from iblai.models.paginated_course_license import PaginatedCourseLicense
from iblai.models.paginated_course_license_assignment import PaginatedCourseLicenseAssignment
from iblai.models.paginated_course_license_group_assignment import PaginatedCourseLicenseGroupAssignment
from iblai.models.paginated_course_suggestion import PaginatedCourseSuggestion
from iblai.models.paginated_data_set_list import PaginatedDataSetList
from iblai.models.paginated_edx_course_list import PaginatedEdxCourseList
from iblai.models.paginated_email_prompt_list_list import PaginatedEmailPromptListList
from iblai.models.paginated_heygen_marketing_video_list_list import PaginatedHeygenMarketingVideoListList
from iblai.models.paginated_heygen_template_response_single_list import PaginatedHeygenTemplateResponseSingleList
from iblai.models.paginated_job_run_list import PaginatedJobRunList
from iblai.models.paginated_mcp_server_list import PaginatedMCPServerList
from iblai.models.paginated_mentor_list import PaginatedMentorList
from iblai.models.paginated_moderation_log_list import PaginatedModerationLogList
from iblai.models.paginated_pathway_group_suggestion import PaginatedPathwayGroupSuggestion
from iblai.models.paginated_pathway_suggestion import PaginatedPathwaySuggestion
from iblai.models.paginated_periodic_agent_list import PaginatedPeriodicAgentList
from iblai.models.paginated_periodic_agent_log_list import PaginatedPeriodicAgentLogList
from iblai.models.paginated_platform_invitation import PaginatedPlatformInvitation
from iblai.models.paginated_platform_license import PaginatedPlatformLicense
from iblai.models.paginated_play_wright_script_list import PaginatedPlayWrightScriptList
from iblai.models.paginated_program_group_suggestion import PaginatedProgramGroupSuggestion
from iblai.models.paginated_program_invitation import PaginatedProgramInvitation
from iblai.models.paginated_program_license import PaginatedProgramLicense
from iblai.models.paginated_program_license_assignment import PaginatedProgramLicenseAssignment
from iblai.models.paginated_program_license_group_assignment import PaginatedProgramLicenseGroupAssignment
from iblai.models.paginated_program_suggestion import PaginatedProgramSuggestion
from iblai.models.paginated_rbac_group_list import PaginatedRbacGroupList
from iblai.models.paginated_rbac_policy_list import PaginatedRbacPolicyList
from iblai.models.paginated_rbac_role_list import PaginatedRbacRoleList
from iblai.models.paginated_retriever_document_embedding_list import PaginatedRetrieverDocumentEmbeddingList
from iblai.models.paginated_section_list import PaginatedSectionList
from iblai.models.paginated_skill import PaginatedSkill
from iblai.models.paginated_sub_section_list import PaginatedSubSectionList
from iblai.models.paginated_topic_statistics_response import PaginatedTopicStatisticsResponse
from iblai.models.paginated_training_list import PaginatedTrainingList
from iblai.models.paginated_unit_list import PaginatedUnitList
from iblai.models.paginated_user_app_list import PaginatedUserAppList
from iblai.models.paginated_user_edx_memory_list import PaginatedUserEdxMemoryList
from iblai.models.paginated_user_license import PaginatedUserLicense
from iblai.models.paginated_user_license_assignment import PaginatedUserLicenseAssignment
from iblai.models.paginated_user_license_group_assignment import PaginatedUserLicenseGroupAssignment
from iblai.models.paginated_voice_list import PaginatedVoiceList
from iblai.models.pagination import Pagination
from iblai.models.patched_bot_command import PatchedBotCommand
from iblai.models.patched_bot_create import PatchedBotCreate
from iblai.models.patched_call_configuration import PatchedCallConfiguration
from iblai.models.patched_conversations import PatchedConversations
from iblai.models.patched_course_creation_task_file import PatchedCourseCreationTaskFile
from iblai.models.patched_credential_request import PatchedCredentialRequest
from iblai.models.patched_data_set import PatchedDataSet
from iblai.models.patched_discord_config import PatchedDiscordConfig
from iblai.models.patched_discord_user_config import PatchedDiscordUserConfig
from iblai.models.patched_llm_credential_request import PatchedLLMCredentialRequest
from iblai.models.patched_mcp_server import PatchedMCPServer
from iblai.models.patched_media_resource import PatchedMediaResource
from iblai.models.patched_mentor_category_group_create import PatchedMentorCategoryGroupCreate
from iblai.models.patched_mentor_create import PatchedMentorCreate
from iblai.models.patched_notification import PatchedNotification
from iblai.models.patched_periodic_agent_create import PatchedPeriodicAgentCreate
from iblai.models.patched_platform_public_metadata import PatchedPlatformPublicMetadata
from iblai.models.patched_play_wright_script import PatchedPlayWrightScript
from iblai.models.patched_prompt import PatchedPrompt
from iblai.models.patched_prompt_prompt_visibility import PatchedPromptPromptVisibility
from iblai.models.patched_rbac_group import PatchedRbacGroup
from iblai.models.patched_rbac_policy import PatchedRbacPolicy
from iblai.models.patched_rbac_role import PatchedRbacRole
from iblai.models.patched_section import PatchedSection
from iblai.models.patched_skill_threshold import PatchedSkillThreshold
from iblai.models.patched_slack_config import PatchedSlackConfig
from iblai.models.patched_slack_user_config import PatchedSlackUserConfig
from iblai.models.patched_sub_section import PatchedSubSection
from iblai.models.patched_teams_config import PatchedTeamsConfig
from iblai.models.patched_training_create import PatchedTrainingCreate
from iblai.models.patched_unit import PatchedUnit
from iblai.models.patched_webex_config import PatchedWebexConfig
from iblai.models.patched_whatsapp_config import PatchedWhatsappConfig
from iblai.models.patched_whatsapp_user_config import PatchedWhatsappUserConfig
from iblai.models.pathway import Pathway
from iblai.models.pathway_completion_response import PathwayCompletionResponse
from iblai.models.pathway_create_update_request import PathwayCreateUpdateRequest
from iblai.models.pathway_delete_response import PathwayDeleteResponse
from iblai.models.pathway_enrollment import PathwayEnrollment
from iblai.models.pathway_enrollment_plus import PathwayEnrollmentPlus
from iblai.models.pathway_enrollment_request import PathwayEnrollmentRequest
from iblai.models.pathway_group_suggestion_create import PathwayGroupSuggestionCreate
from iblai.models.pathway_group_suggestion_detail import PathwayGroupSuggestionDetail
from iblai.models.pathway_self_enrollment_request import PathwaySelfEnrollmentRequest
from iblai.models.pathway_suggestion_bulk_create import PathwaySuggestionBulkCreate
from iblai.models.pathway_suggestion_create import PathwaySuggestionCreate
from iblai.models.pathway_suggestion_detail import PathwaySuggestionDetail
from iblai.models.per_learner_course_last_access_data import PerLearnerCourseLastAccessData
from iblai.models.per_learner_course_videos_watched import PerLearnerCourseVideosWatched
from iblai.models.per_learner_course_videos_watched_data import PerLearnerCourseVideosWatchedData
from iblai.models.per_learner_last_access import PerLearnerLastAccess
from iblai.models.per_learner_last_access_data import PerLearnerLastAccessData
from iblai.models.per_learner_time_spent_in_course_tree import PerLearnerTimeSpentInCourseTree
from iblai.models.performance_grades_per_course import PerformanceGradesPerCourse
from iblai.models.performance_grades_per_course_data import PerformanceGradesPerCourseData
from iblai.models.periodic_agent import PeriodicAgent
from iblai.models.periodic_agent_create import PeriodicAgentCreate
from iblai.models.periodic_agent_log import PeriodicAgentLog
from iblai.models.periodic_agent_log_status_enum import PeriodicAgentLogStatusEnum
from iblai.models.periodic_task import PeriodicTask
from iblai.models.perlearner_course_progress import PerlearnerCourseProgress
from iblai.models.perlearner_course_progress_data import PerlearnerCourseProgressData
from iblai.models.perlearner_engagement_videos_data import PerlearnerEngagementVideosData
from iblai.models.perlearner_engagement_videos_watched_per_course import PerlearnerEngagementVideosWatchedPerCourse
from iblai.models.perlearner_grade_summary import PerlearnerGradeSummary
from iblai.models.perlearner_grade_summary_data import PerlearnerGradeSummaryData
from iblai.models.perlearner_grade_with_cut_off import PerlearnerGradeWithCutOff
from iblai.models.perlearner_grade_with_cut_off_data import PerlearnerGradeWithCutOffData
from iblai.models.perlearner_grading_per_course_api import PerlearnerGradingPerCourseAPI
from iblai.models.perlearner_grading_per_course_api_data import PerlearnerGradingPerCourseAPIData
from iblai.models.perlearner_user_list import PerlearnerUserList
from iblai.models.perlearner_user_list_data import PerlearnerUserListData
from iblai.models.pie_chart_data import PieChartData
from iblai.models.pie_chart_segment import PieChartSegment
from iblai.models.pinned_message_create import PinnedMessageCreate
from iblai.models.pinned_message_get import PinnedMessageGet
from iblai.models.pinned_message_request import PinnedMessageRequest
from iblai.models.platform import Platform
from iblai.models.platform_api_key import PlatformApiKey
from iblai.models.platform_invitation_create import PlatformInvitationCreate
from iblai.models.platform_invitation_detail import PlatformInvitationDetail
from iblai.models.platform_invitation_redemption import PlatformInvitationRedemption
from iblai.models.platform_license_create import PlatformLicenseCreate
from iblai.models.platform_license_detail import PlatformLicenseDetail
from iblai.models.platform_license_update import PlatformLicenseUpdate
from iblai.models.platform_list import PlatformList
from iblai.models.platform_list_status_enum import PlatformListStatusEnum
from iblai.models.platform_public_metadata import PlatformPublicMetadata
from iblai.models.platform_skill_point_bulk_request import PlatformSkillPointBulkRequest
from iblai.models.platform_skill_point_bulk_response import PlatformSkillPointBulkResponse
from iblai.models.platform_skill_point_group_request import PlatformSkillPointGroupRequest
from iblai.models.platform_skill_point_request import PlatformSkillPointRequest
from iblai.models.platform_skill_point_response import PlatformSkillPointResponse
from iblai.models.platform_update_post_request import PlatformUpdatePostRequest
from iblai.models.play_wright_script import PlayWrightScript
from iblai.models.points_percentile import PointsPercentile
from iblai.models.predictive_analytics_request import PredictiveAnalyticsRequest
from iblai.models.predictive_analytics_response import PredictiveAnalyticsResponse
from iblai.models.preview_response import PreviewResponse
from iblai.models.previous_agent_status_enum import PreviousAgentStatusEnum
from iblai.models.product import Product
from iblai.models.product_table import ProductTable
from iblai.models.program import Program
from iblai.models.program_completion_response import ProgramCompletionResponse
from iblai.models.program_course_position import ProgramCoursePosition
from iblai.models.program_create_update_request import ProgramCreateUpdateRequest
from iblai.models.program_delete_response import ProgramDeleteResponse
from iblai.models.program_enrollment import ProgramEnrollment
from iblai.models.program_enrollment_plus import ProgramEnrollmentPlus
from iblai.models.program_enrollment_search_response import ProgramEnrollmentSearchResponse
from iblai.models.program_group_suggestion_create import ProgramGroupSuggestionCreate
from iblai.models.program_group_suggestion_detail import ProgramGroupSuggestionDetail
from iblai.models.program_invitation_create import ProgramInvitationCreate
from iblai.models.program_invitation_detail import ProgramInvitationDetail
from iblai.models.program_invitation_redemption import ProgramInvitationRedemption
from iblai.models.program_license_assignment_create import ProgramLicenseAssignmentCreate
from iblai.models.program_license_assignment_detail import ProgramLicenseAssignmentDetail
from iblai.models.program_license_create_detail import ProgramLicenseCreateDetail
from iblai.models.program_license_detail import ProgramLicenseDetail
from iblai.models.program_license_group_assignment_create import ProgramLicenseGroupAssignmentCreate
from iblai.models.program_license_group_assignment_detail import ProgramLicenseGroupAssignmentDetail
from iblai.models.program_license_update_detail import ProgramLicenseUpdateDetail
from iblai.models.program_metadata_request import ProgramMetadataRequest
from iblai.models.program_metadata_response import ProgramMetadataResponse
from iblai.models.program_review import ProgramReview
from iblai.models.program_review_info_response import ProgramReviewInfoResponse
from iblai.models.program_review_paginated_response import ProgramReviewPaginatedResponse
from iblai.models.program_review_request import ProgramReviewRequest
from iblai.models.program_search import ProgramSearch
from iblai.models.program_suggestion_bulk_create import ProgramSuggestionBulkCreate
from iblai.models.program_suggestion_create import ProgramSuggestionCreate
from iblai.models.program_suggestion_detail import ProgramSuggestionDetail
from iblai.models.program_type_enum import ProgramTypeEnum
from iblai.models.prompt import Prompt
from iblai.models.prompt_category import PromptCategory
from iblai.models.prompt_facet import PromptFacet
from iblai.models.prompt_search_response import PromptSearchResponse
from iblai.models.prompt_visibility_enum import PromptVisibilityEnum
from iblai.models.provider05c_enum import Provider05cEnum
from iblai.models.provider637_enum import Provider637Enum
from iblai.models.provider63a_enum import Provider63aEnum
from iblai.models.provider_association_stripe_callback_retrieve404_response import ProviderAssociationStripeCallbackRetrieve404Response
from iblai.models.question_card_tag import QuestionCardTag
from iblai.models.question_request import QuestionRequest
from iblai.models.question_response import QuestionResponse
from iblai.models.rating_enum import RatingEnum
from iblai.models.rating_record import RatingRecord
from iblai.models.rbac_base_role import RbacBaseRole
from iblai.models.rbac_group import RbacGroup
from iblai.models.rbac_platform import RbacPlatform
from iblai.models.rbac_policy import RbacPolicy
from iblai.models.rbac_policy_group import RbacPolicyGroup
from iblai.models.rbac_role import RbacRole
from iblai.models.rbac_user import RbacUser
from iblai.models.recently_accessed_mentor import RecentlyAccessedMentor
from iblai.models.recipient import Recipient
from iblai.models.recommend_course_block import RecommendCourseBlock
from iblai.models.recommend_course_response import RecommendCourseResponse
from iblai.models.recommendation_search_api import RecommendationSearchAPI
from iblai.models.recommended_courses_response import RecommendedCoursesResponse
from iblai.models.redirect_token_request import RedirectTokenRequest
from iblai.models.redirect_token_response import RedirectTokenResponse
from iblai.models.related_text import RelatedText
from iblai.models.report_create import ReportCreate
from iblai.models.report_data import ReportData
from iblai.models.report_detail import ReportDetail
from iblai.models.report_list import ReportList
from iblai.models.report_request import ReportRequest
from iblai.models.report_status import ReportStatus
from iblai.models.reported_role import ReportedRole
from iblai.models.reported_role_create_update_request import ReportedRoleCreateUpdateRequest
from iblai.models.reported_skill import ReportedSkill
from iblai.models.request_data_variable import RequestDataVariable
from iblai.models.resource import Resource
from iblai.models.resource_completion import ResourceCompletion
from iblai.models.resource_completion_request import ResourceCompletionRequest
from iblai.models.resource_create_update import ResourceCreateUpdate
from iblai.models.resource_delete_response import ResourceDeleteResponse
from iblai.models.resource_point import ResourcePoint
from iblai.models.resource_scrapped_data import ResourceScrappedData
from iblai.models.resource_scrapped_data_status import ResourceScrappedDataStatus
from iblai.models.resource_scrapped_data_status_enum import ResourceScrappedDataStatusEnum
from iblai.models.response_data_variable import ResponseDataVariable
from iblai.models.retreiver_train_view_request import RetreiverTrainViewRequest
from iblai.models.retreiver_train_view_response import RetreiverTrainViewResponse
from iblai.models.retrieve_task import RetrieveTask
from iblai.models.retriever_document_embedding import RetrieverDocumentEmbedding
from iblai.models.retriever_document_embedding_access import RetrieverDocumentEmbeddingAccess
from iblai.models.retriever_document_embedding_request import RetrieverDocumentEmbeddingRequest
from iblai.models.retriever_document_embedding_training_status import RetrieverDocumentEmbeddingTrainingStatus
from iblai.models.retriever_request_search import RetrieverRequestSearch
from iblai.models.retriever_request_search_document import RetrieverRequestSearchDocument
from iblai.models.retriever_response_search import RetrieverResponseSearch
from iblai.models.reuest_data_variable_list import ReuestDataVariableList
from iblai.models.revenue_by_product import RevenueByProduct
from iblai.models.role import Role
from iblai.models.role_create_update_request import RoleCreateUpdateRequest
from iblai.models.run_mentor_eval import RunMentorEval
from iblai.models.scan_webhook_request import ScanWebhookRequest
from iblai.models.scan_webhook_response import ScanWebhookResponse
from iblai.models.section import Section
from iblai.models.section_with_children import SectionWithChildren
from iblai.models.seed_mentors_view import SeedMentorsView
from iblai.models.send_notification import SendNotification
from iblai.models.send_response import SendResponse
from iblai.models.sentiment_summary import SentimentSummary
from iblai.models.session_browser_screenshot import SessionBrowserScreenshot
from iblai.models.session_detail import SessionDetail
from iblai.models.session_memory_storage import SessionMemoryStorage
from iblai.models.shell_logs import ShellLogs
from iblai.models.skill import Skill
from iblai.models.skill_create_update_request import SkillCreateUpdateRequest
from iblai.models.skill_detail import SkillDetail
from iblai.models.skill_info import SkillInfo
from iblai.models.skill_threshold import SkillThreshold
from iblai.models.slack_config import SlackConfig
from iblai.models.slack_user_config import SlackUserConfig
from iblai.models.slack_webhook import SlackWebhook
from iblai.models.spaced_repetition_learning_path import SpacedRepetitionLearningPath
from iblai.models.spaced_repetition_question_stats import SpacedRepetitionQuestionStats
from iblai.models.star_mentor import StarMentor
from iblai.models.state_enum import StateEnum
from iblai.models.status6ee_enum import Status6eeEnum
from iblai.models.step import Step
from iblai.models.step_status_enum import StepStatusEnum
from iblai.models.stripe_billing_page_identifier_response import StripeBillingPageIdentifierResponse
from iblai.models.stripe_checkout_session_request import StripeCheckoutSessionRequest
from iblai.models.stripe_checkout_session_request_mode_enum import StripeCheckoutSessionRequestModeEnum
from iblai.models.stripe_checkout_session_response import StripeCheckoutSessionResponse
from iblai.models.stripe_context import StripeContext
from iblai.models.stripe_customer_portal_request import StripeCustomerPortalRequest
from iblai.models.stripe_customer_portal_response import StripeCustomerPortalResponse
from iblai.models.stripe_local_product import StripeLocalProduct
from iblai.models.stripe_new_user_tenant_launch_request import StripeNewUserTenantLaunchRequest
from iblai.models.stripe_subscription_renewal_request import StripeSubscriptionRenewalRequest
from iblai.models.stripe_subscription_renewal_response import StripeSubscriptionRenewalResponse
from iblai.models.stt_provider_enum import SttProviderEnum
from iblai.models.student_chat_message import StudentChatMessage
from iblai.models.styles_view import StylesView
from iblai.models.sub_section import SubSection
from iblai.models.sub_section_with_children import SubSectionWithChildren
from iblai.models.sub_time_child import SubTimeChild
from iblai.models.summary import Summary
from iblai.models.tags_view import TagsView
from iblai.models.target_system_enum import TargetSystemEnum
from iblai.models.task_view import TaskView
from iblai.models.teams_config import TeamsConfig
from iblai.models.teams_webhook import TeamsWebhook
from iblai.models.template_mentor import TemplateMentor
from iblai.models.tenant_launch_error import TenantLaunchError
from iblai.models.tenant_launch_failed import TenantLaunchFailed
from iblai.models.tenant_launch_request import TenantLaunchRequest
from iblai.models.tenant_launch_response import TenantLaunchResponse
from iblai.models.tenant_mentor_traces import TenantMentorTraces
from iblai.models.theme_enum import ThemeEnum
from iblai.models.time_child_data import TimeChildData
from iblai.models.time_detail import TimeDetail
from iblai.models.time_detail_child import TimeDetailChild
from iblai.models.time_detail_data import TimeDetailData
from iblai.models.time_spent_by_users_in_course import TimeSpentByUsersInCourse
from iblai.models.time_spent_by_users_in_course_data import TimeSpentByUsersInCourseData
from iblai.models.time_spent_per_course import TimeSpentPerCourse
from iblai.models.time_spent_per_course_data import TimeSpentPerCourseData
from iblai.models.time_spent_per_user_response import TimeSpentPerUserResponse
from iblai.models.time_spent_update_request import TimeSpentUpdateRequest
from iblai.models.time_spent_update_response import TimeSpentUpdateResponse
from iblai.models.token_proxy_input import TokenProxyInput
from iblai.models.token_proxy_output import TokenProxyOutput
from iblai.models.token_proxy_output_serializer_data import TokenProxyOutputSerializerData
from iblai.models.token_proxy_user import TokenProxyUser
from iblai.models.tones_view import TonesView
from iblai.models.tool_response import ToolResponse
from iblai.models.topic_model import TopicModel
from iblai.models.topic_record import TopicRecord
from iblai.models.topic_statistics import TopicStatistics
from iblai.models.topic_statistics_response import TopicStatisticsResponse
from iblai.models.topic_summary_view import TopicSummaryView
from iblai.models.train_chat_session_document_view import TrainChatSessionDocumentView
from iblai.models.train_chat_session_document_view_request import TrainChatSessionDocumentViewRequest
from iblai.models.train_document_view_request import TrainDocumentViewRequest
from iblai.models.train_document_view_response import TrainDocumentViewResponse
from iblai.models.training import Training
from iblai.models.training_create import TrainingCreate
from iblai.models.training_status_enum import TrainingStatusEnum
from iblai.models.transport_enum import TransportEnum
from iblai.models.trend_entry import TrendEntry
from iblai.models.trigger_request import TriggerRequest
from iblai.models.trigger_response import TriggerResponse
from iblai.models.tts_provider_enum import TtsProviderEnum
from iblai.models.type_c42_enum import TypeC42Enum
from iblai.models.unit import Unit
from iblai.models.unit_with_children import UnitWithChildren
from iblai.models.uploaded_image import UploadedImage
from iblai.models.use_main_creds import UseMainCreds
from iblai.models.user_all_chat_memory_view import UserAllChatMemoryView
from iblai.models.user_app import UserApp
from iblai.models.user_catalog_item_memory_view import UserCatalogItemMemoryView
from iblai.models.user_chat_by_period import UserChatByPeriod
from iblai.models.user_chat_feedback import UserChatFeedback
from iblai.models.user_chat_feedback_count import UserChatFeedbackCount
from iblai.models.user_chat_memory_status_request_view import UserChatMemoryStatusRequestView
from iblai.models.user_chat_memory_status_view import UserChatMemoryStatusView
from iblai.models.user_chat_memory_update_view import UserChatMemoryUpdateView
from iblai.models.user_count_record import UserCountRecord
from iblai.models.user_delete_api_error import UserDeleteAPIError
from iblai.models.user_delete_api_request import UserDeleteAPIRequest
from iblai.models.user_delete_api_response import UserDeleteAPIResponse
from iblai.models.user_edx_memory import UserEdxMemory
from iblai.models.user_info import UserInfo
from iblai.models.user_license_assignment_create import UserLicenseAssignmentCreate
from iblai.models.user_license_assignment_detail import UserLicenseAssignmentDetail
from iblai.models.user_license_create import UserLicenseCreate
from iblai.models.user_license_detail import UserLicenseDetail
from iblai.models.user_license_group_assignment_create import UserLicenseGroupAssignmentCreate
from iblai.models.user_license_group_assignment_detail import UserLicenseGroupAssignmentDetail
from iblai.models.user_license_update import UserLicenseUpdate
from iblai.models.user_memory_context_request import UserMemoryContextRequest
from iblai.models.user_memory_context_response import UserMemoryContextResponse
from iblai.models.user_metric import UserMetric
from iblai.models.user_metrics_response import UserMetricsResponse
from iblai.models.user_platform_link import UserPlatformLink
from iblai.models.user_platform_management_list_view_get_response import UserPlatformManagementListViewGetResponse
from iblai.models.user_platform_view_post_request import UserPlatformViewPostRequest
from iblai.models.user_proxy_bulk_request import UserProxyBulkRequest
from iblai.models.user_proxy_get_response import UserProxyGetResponse
from iblai.models.user_proxy_post_request import UserProxyPostRequest
from iblai.models.user_proxy_post_response import UserProxyPostResponse
from iblai.models.user_search_response import UserSearchResponse
from iblai.models.user_search_view_get_response import UserSearchViewGetResponse
from iblai.models.user_sentiment_count_view import UserSentimentCountView
from iblai.models.user_skill import UserSkill
from iblai.models.user_skill_points_percentile import UserSkillPointsPercentile
from iblai.models.user_trend_by_period import UserTrendByPeriod
from iblai.models.validate_source_response import ValidateSourceResponse
from iblai.models.value import Value
from iblai.models.value_data import ValueData
from iblai.models.vector_result import VectorResult
from iblai.models.verify_gcp_market_place_failed_response import VerifyGCPMarketPlaceFailedResponse
from iblai.models.verify_gcp_market_place_request import VerifyGCPMarketPlaceRequest
from iblai.models.verify_gcp_market_place_response import VerifyGCPMarketPlaceResponse
from iblai.models.video_block import VideoBlock
from iblai.models.video_caption import VideoCaption
from iblai.models.video_engagement_per_course import VideoEngagementPerCourse
from iblai.models.video_engagement_per_course_data import VideoEngagementPerCourseData
from iblai.models.videos_count import VideosCount
from iblai.models.videos_count_data import VideosCountData
from iblai.models.videos_in_course_summary import VideosInCourseSummary
from iblai.models.videos_in_course_summary_data import VideosInCourseSummaryData
from iblai.models.videos_specific_course import VideosSpecificCourse
from iblai.models.videos_specific_course_data import VideosSpecificCourseData
from iblai.models.videos_watched_sub_section import VideosWatchedSubSection
from iblai.models.voice import Voice
from iblai.models.watched_videos_per_course import WatchedVideosPerCourse
from iblai.models.watched_videos_per_course_data import WatchedVideosPerCourseData
from iblai.models.watched_videos_per_user import WatchedVideosPerUser
from iblai.models.watched_videos_per_user_data import WatchedVideosPerUserData
from iblai.models.web_resource import WebResource
from iblai.models.web_resource_card import WebResourceCard
from iblai.models.web_resources_query import WebResourcesQuery
from iblai.models.webex_config import WebexConfig
from iblai.models.webex_webhook import WebexWebhook
from iblai.models.what_app_web_hook import WhatAppWebHook
from iblai.models.whatsapp_config import WhatsappConfig
from iblai.models.whatsapp_user_config import WhatsappUserConfig
from iblai.models.whitelisted_domain import WhitelistedDomain



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.api.notification_api import NotificationApi


class TestNotificationApi(unittest.TestCase):
    """NotificationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = NotificationApi()

    def tearDown(self) -> None:
        pass

    def test_notification_v1_orgs_notifications_bulk_update_partial_update(self) -> None:
        """Test case for notification_v1_orgs_notifications_bulk_update_partial_update

        """
        pass

    def test_notification_v1_orgs_notifications_retrieve(self) -> None:
        """Test case for notification_v1_orgs_notifications_retrieve

        """
        pass

    def test_notification_v1_orgs_notifications_update(self) -> None:
        """Test case for notification_v1_orgs_notifications_update

        """
        pass

    def test_notification_v1_orgs_users_notifications_bulk_update_partial_update(self) -> None:
        """Test case for notification_v1_orgs_users_notifications_bulk_update_partial_update

        """
        pass

    def test_notification_v1_orgs_users_notifications_count_retrieve(self) -> None:
        """Test case for notification_v1_orgs_users_notifications_count_retrieve

        """
        pass

    def test_notification_v1_orgs_users_notifications_destroy(self) -> None:
        """Test case for notification_v1_orgs_users_notifications_destroy

        """
        pass

    def test_notification_v1_orgs_users_notifications_retrieve(self) -> None:
        """Test case for notification_v1_orgs_users_notifications_retrieve

        """
        pass

    def test_notification_v1_orgs_users_notifications_update(self) -> None:
        """Test case for notification_v1_orgs_users_notifications_update

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.pinned_message_get import PinnedMessageGet

class TestPinnedMessageGet(unittest.TestCase):
    """PinnedMessageGet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PinnedMessageGet:
        """Test PinnedMessageGet
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PinnedMessageGet`
        """
        model = PinnedMessageGet()
        if include_optional:
            return PinnedMessageGet(
                session_id = '',
                mentor = iblai.models.mentor.Mentor(
                    name = '', 
                    unique_id = '', 
                    flow = null, 
                    slug = 'z', 
                    platform = '', 
                    allow_anonymous = True, 
                    metadata = null, 
                    enable_moderation = True, 
                    enable_post_processing_system = True, 
                    enable_openai_assistant = True, 
                    enable_total_grounding = True, 
                    enable_suggested_prompts = True, 
                    enable_guided_prompts = True, 
                    guided_prompt_instructions = '', 
                    google_voice = 56, 
                    openai_voice = 56, 
                    categories = [
                        iblai.models.mentor_category.MentorCategory(
                            id = 56, 
                            name = '', 
                            description = '', 
                            category_group = 56, 
                            audience = iblai.models.mentor_audience.MentorAudience(
                                id = 56, 
                                name = '', 
                                description = '', ), 
                            audiences = [
                                iblai.models.mentor_audience.MentorAudience(
                                    id = 56, 
                                    name = '', 
                                    description = '', )
                                ], )
                        ], 
                    proactive_prompt = '', 
                    moderation_system_prompt = '', 
                    post_processing_prompt = '', 
                    moderation_response = '', 
                    safety_system_prompt = '', 
                    safety_response = '', 
                    enable_safety_system = True, 
                    proactive_response = '', 
                    greeting_method = null, 
                    call_configuration = iblai.models.call_configuration.CallConfiguration(
                        id = 56, 
                        mentor = 56, 
                        mode = 'realtime', 
                        tts_provider = 'openai', 
                        stt_provider = 'openai', 
                        llm_provider = 'openai', 
                        use_function_calling_for_rag = True, 
                        google_voice = iblai.models.voice.Voice(
                            id = 56, 
                            name = '', 
                            provider = 'openai', 
                            language = '', 
                            description = '', 
                            audio_url = '', ), 
                        openai_voice = iblai.models.voice.Voice(
                            id = 56, 
                            name = '', 
                            provider = 'openai', 
                            language = '', 
                            description = '', 
                            audio_url = '', ), 
                        openai_voice_id = 56, 
                        google_voice_id = 56, 
                        enable_video = True, 
                        platform_key = '', ), 
                    mcp_servers = [
                        iblai.models.mcp_server.MCPServer(
                            id = 56, 
                            platform = 56, 
                            name = '', 
                            url = '', 
                            transport = 'sse', 
                            headers = null, 
                            platform_key = '', 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                        ], 
                    last_accessed_by = 56, 
                    recently_accessed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    created_by = '', 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                messages = [
                    iblai.models.chat_history.ChatHistory(
                        id = 56, 
                        message = null, 
                        inserted_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        title = '', 
                        feedback = null, 
                        document_sources = null, )
                    ]
            )
        else:
            return PinnedMessageGet(
                session_id = '',
                mentor = iblai.models.mentor.Mentor(
                    name = '', 
                    unique_id = '', 
                    flow = null, 
                    slug = 'z', 
                    platform = '', 
                    allow_anonymous = True, 
                    metadata = null, 
                    enable_moderation = True, 
                    enable_post_processing_system = True, 
                    enable_openai_assistant = True, 
                    enable_total_grounding = True, 
                    enable_suggested_prompts = True, 
                    enable_guided_prompts = True, 
                    guided_prompt_instructions = '', 
                    google_voice = 56, 
                    openai_voice = 56, 
                    categories = [
                        iblai.models.mentor_category.MentorCategory(
                            id = 56, 
                            name = '', 
                            description = '', 
                            category_group = 56, 
                            audience = iblai.models.mentor_audience.MentorAudience(
                                id = 56, 
                                name = '', 
                                description = '', ), 
                            audiences = [
                                iblai.models.mentor_audience.MentorAudience(
                                    id = 56, 
                                    name = '', 
                                    description = '', )
                                ], )
                        ], 
                    proactive_prompt = '', 
                    moderation_system_prompt = '', 
                    post_processing_prompt = '', 
                    moderation_response = '', 
                    safety_system_prompt = '', 
                    safety_response = '', 
                    enable_safety_system = True, 
                    proactive_response = '', 
                    greeting_method = null, 
                    call_configuration = iblai.models.call_configuration.CallConfiguration(
                        id = 56, 
                        mentor = 56, 
                        mode = 'realtime', 
                        tts_provider = 'openai', 
                        stt_provider = 'openai', 
                        llm_provider = 'openai', 
                        use_function_calling_for_rag = True, 
                        google_voice = iblai.models.voice.Voice(
                            id = 56, 
                            name = '', 
                            provider = 'openai', 
                            language = '', 
                            description = '', 
                            audio_url = '', ), 
                        openai_voice = iblai.models.voice.Voice(
                            id = 56, 
                            name = '', 
                            provider = 'openai', 
                            language = '', 
                            description = '', 
                            audio_url = '', ), 
                        openai_voice_id = 56, 
                        google_voice_id = 56, 
                        enable_video = True, 
                        platform_key = '', ), 
                    mcp_servers = [
                        iblai.models.mcp_server.MCPServer(
                            id = 56, 
                            platform = 56, 
                            name = '', 
                            url = '', 
                            transport = 'sse', 
                            headers = null, 
                            platform_key = '', 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                        ], 
                    last_accessed_by = 56, 
                    recently_accessed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    created_by = '', 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                messages = [
                    iblai.models.chat_history.ChatHistory(
                        id = 56, 
                        message = null, 
                        inserted_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        title = '', 
                        feedback = null, 
                        document_sources = null, )
                    ],
        )
        """

    def testPinnedMessageGet(self):
        """Test PinnedMessageGet"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class PathwayEnrollmentRequest(BaseModel):
    """
    Serializer for pathway enrollment request parameters.
    """ # noqa: E501
    user_id: Optional[StrictStr] = Field(default=None, description="User ID for enrollment")
    username: Optional[StrictStr] = Field(default=None, description="Username for enrollment")
    pathway_id: Optional[StrictStr] = Field(default=None, description="Pathway ID for enrollment")
    pathway_uuid: Optional[StrictStr] = Field(default=None, description="Pathway UUID for enrollment")
    pathway_key: Optional[StrictStr] = Field(default=None, description="Pathway key for enrollment")
    slug: Optional[StrictStr] = Field(default=None, description="Pathway slug for enrollment")
    org: Optional[StrictStr] = Field(default=None, description="Organization for the pathway")
    platform_key: Optional[StrictStr] = Field(default=None, description="Platform key for the pathway")
    include_default_platform: Optional[StrictBool] = Field(default=None, description="Include enrollments from default platform")
    include_metadata: Optional[StrictBool] = Field(default=True, description="Include metadata in the response")
    active: Optional[StrictBool] = Field(default=True, description="Whether the enrollment should be active")
    __properties: ClassVar[List[str]] = ["user_id", "username", "pathway_id", "pathway_uuid", "pathway_key", "slug", "org", "platform_key", "include_default_platform", "include_metadata", "active"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PathwayEnrollmentRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PathwayEnrollmentRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "user_id": obj.get("user_id"),
            "username": obj.get("username"),
            "pathway_id": obj.get("pathway_id"),
            "pathway_uuid": obj.get("pathway_uuid"),
            "pathway_key": obj.get("pathway_key"),
            "slug": obj.get("slug"),
            "org": obj.get("org"),
            "platform_key": obj.get("platform_key"),
            "include_default_platform": obj.get("include_default_platform"),
            "include_metadata": obj.get("include_metadata") if obj.get("include_metadata") is not None else True,
            "active": obj.get("active") if obj.get("active") is not None else True
        })
        return _obj





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.api.media_resources_api import MediaResourcesApi


class TestMediaResourcesApi(unittest.TestCase):
    """MediaResourcesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = MediaResourcesApi()

    def tearDown(self) -> None:
        pass

    def test_media_orgs_users_media_media_resources_by_item_retrieve(self) -> None:
        """Test case for media_orgs_users_media_media_resources_by_item_retrieve

        """
        pass

    def test_media_orgs_users_media_media_resources_create(self) -> None:
        """Test case for media_orgs_users_media_media_resources_create

        """
        pass

    def test_media_orgs_users_media_media_resources_destroy(self) -> None:
        """Test case for media_orgs_users_media_media_resources_destroy

        """
        pass

    def test_media_orgs_users_media_media_resources_list(self) -> None:
        """Test case for media_orgs_users_media_media_resources_list

        """
        pass

    def test_media_orgs_users_media_media_resources_partial_update(self) -> None:
        """Test case for media_orgs_users_media_media_resources_partial_update

        """
        pass

    def test_media_orgs_users_media_media_resources_retrieve(self) -> None:
        """Test case for media_orgs_users_media_media_resources_retrieve

        """
        pass

    def test_media_orgs_users_media_media_resources_search_retrieve(self) -> None:
        """Test case for media_orgs_users_media_media_resources_search_retrieve

        """
        pass

    def test_media_orgs_users_media_media_resources_update(self) -> None:
        """Test case for media_orgs_users_media_media_resources_update

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class Observation(BaseModel):
    """
    Observation
    """ # noqa: E501
    id: StrictStr
    trace_id: StrictStr = Field(alias="traceId")
    project_id: StrictStr = Field(alias="projectId")
    type: StrictStr
    start_time: datetime = Field(alias="startTime")
    end_time: datetime = Field(alias="endTime")
    name: StrictStr
    metadata: Optional[Dict[str, Any]]
    parent_observation_id: Optional[StrictStr] = Field(alias="parentObservationId")
    level: StrictStr
    status_message: Optional[StrictStr] = Field(alias="statusMessage")
    version: Optional[StrictStr]
    created_at: datetime = Field(alias="createdAt")
    model: Optional[StrictStr]
    model_parameters: Optional[Dict[str, Any]] = Field(alias="modelParameters")
    input: Optional[Any]
    output: Optional[Any]
    prompt_tokens: StrictInt = Field(alias="promptTokens")
    completion_tokens: StrictInt = Field(alias="completionTokens")
    total_tokens: StrictInt = Field(alias="totalTokens")
    unit: StrictStr
    completion_start_time: Optional[datetime] = Field(alias="completionStartTime")
    prompt_id: Optional[StrictStr] = Field(alias="promptId")
    usage: Optional[Dict[str, Any]] = None
    price: Optional[Union[StrictFloat, StrictInt]]
    __properties: ClassVar[List[str]] = ["id", "traceId", "projectId", "type", "startTime", "endTime", "name", "metadata", "parentObservationId", "level", "statusMessage", "version", "createdAt", "model", "modelParameters", "input", "output", "promptTokens", "completionTokens", "totalTokens", "unit", "completionStartTime", "promptId", "usage", "price"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Observation from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if metadata (nullable) is None
        # and model_fields_set contains the field
        if self.metadata is None and "metadata" in self.model_fields_set:
            _dict['metadata'] = None

        # set to None if parent_observation_id (nullable) is None
        # and model_fields_set contains the field
        if self.parent_observation_id is None and "parent_observation_id" in self.model_fields_set:
            _dict['parentObservationId'] = None

        # set to None if status_message (nullable) is None
        # and model_fields_set contains the field
        if self.status_message is None and "status_message" in self.model_fields_set:
            _dict['statusMessage'] = None

        # set to None if version (nullable) is None
        # and model_fields_set contains the field
        if self.version is None and "version" in self.model_fields_set:
            _dict['version'] = None

        # set to None if model (nullable) is None
        # and model_fields_set contains the field
        if self.model is None and "model" in self.model_fields_set:
            _dict['model'] = None

        # set to None if model_parameters (nullable) is None
        # and model_fields_set contains the field
        if self.model_parameters is None and "model_parameters" in self.model_fields_set:
            _dict['modelParameters'] = None

        # set to None if input (nullable) is None
        # and model_fields_set contains the field
        if self.input is None and "input" in self.model_fields_set:
            _dict['input'] = None

        # set to None if output (nullable) is None
        # and model_fields_set contains the field
        if self.output is None and "output" in self.model_fields_set:
            _dict['output'] = None

        # set to None if completion_start_time (nullable) is None
        # and model_fields_set contains the field
        if self.completion_start_time is None and "completion_start_time" in self.model_fields_set:
            _dict['completionStartTime'] = None

        # set to None if prompt_id (nullable) is None
        # and model_fields_set contains the field
        if self.prompt_id is None and "prompt_id" in self.model_fields_set:
            _dict['promptId'] = None

        # set to None if price (nullable) is None
        # and model_fields_set contains the field
        if self.price is None and "price" in self.model_fields_set:
            _dict['price'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Observation from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "traceId": obj.get("traceId"),
            "projectId": obj.get("projectId"),
            "type": obj.get("type"),
            "startTime": obj.get("startTime"),
            "endTime": obj.get("endTime"),
            "name": obj.get("name"),
            "metadata": obj.get("metadata"),
            "parentObservationId": obj.get("parentObservationId"),
            "level": obj.get("level"),
            "statusMessage": obj.get("statusMessage"),
            "version": obj.get("version"),
            "createdAt": obj.get("createdAt"),
            "model": obj.get("model"),
            "modelParameters": obj.get("modelParameters"),
            "input": obj.get("input"),
            "output": obj.get("output"),
            "promptTokens": obj.get("promptTokens"),
            "completionTokens": obj.get("completionTokens"),
            "totalTokens": obj.get("totalTokens"),
            "unit": obj.get("unit"),
            "completionStartTime": obj.get("completionStartTime"),
            "promptId": obj.get("promptId"),
            "usage": obj.get("usage"),
            "price": obj.get("price")
        })
        return _obj





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.patched_periodic_agent_create import PatchedPeriodicAgentCreate

class TestPatchedPeriodicAgentCreate(unittest.TestCase):
    """PatchedPeriodicAgentCreate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PatchedPeriodicAgentCreate:
        """Test PatchedPeriodicAgentCreate
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PatchedPeriodicAgentCreate`
        """
        model = PatchedPeriodicAgentCreate()
        if include_optional:
            return PatchedPeriodicAgentCreate(
                id = 56,
                mentor = 56,
                title = '',
                username = '',
                description = '',
                prompt = '',
                task = iblai.models.periodic_task.PeriodicTask(
                    id = 56, 
                    name = '', 
                    crontab = iblai.models.crontab_schedule.CrontabSchedule(
                        minute = '', 
                        hour = '', 
                        day_of_week = '', 
                        day_of_month = '', 
                        month_of_year = '', ), 
                    one_off = True, 
                    start_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    enabled = True, ),
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                modified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                enabled = True,
                one_off = '',
                platform_key = '',
                pathway = '',
                callback_url = '',
                callback_secret = '',
                parent_session_id = '',
                parent_mentor_id = 56,
                previous_agent = 56,
                previous_agent_status = 'success',
                previous_agent_output = ''
            )
        else:
            return PatchedPeriodicAgentCreate(
        )
        """

    def testPatchedPeriodicAgentCreate(self):
        """Test PatchedPeriodicAgentCreate"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class PlatformListStatusEnum(int, Enum):
    """
    * `-2` - FAILED * `-1` - TERMINATED * `0` - PENDING * `1` - BUILDING * `2` - RUNNING * `3` - PAUSED * `4` - STOPPING * `5` - STOPPED * `6` - REPAIR
    """

    """
    allowed enum values
    """
    NUMBER_MINUS_2 = -2
    NUMBER_MINUS_1 = -1
    NUMBER_0 = 0
    NUMBER_1 = 1
    NUMBER_2 = 2
    NUMBER_3 = 3
    NUMBER_4 = 4
    NUMBER_5 = 5
    NUMBER_6 = 6

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of PlatformListStatusEnum from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictInt
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from iblai.models.institution_type_enum import InstitutionTypeEnum
from typing import Optional, Set
from typing_extensions import Self

class Institution(BaseModel):
    """
    Institution
    """ # noqa: E501
    id: StrictInt
    name: Annotated[str, Field(strict=True, max_length=100)]
    institution_type: Optional[InstitutionTypeEnum] = None
    location: Optional[Annotated[str, Field(strict=True, max_length=100)]] = None
    website: Optional[Annotated[str, Field(strict=True, max_length=255)]] = None
    accreditation: Optional[Annotated[str, Field(strict=True, max_length=100)]] = None
    established_year: Optional[StrictInt] = None
    data: Optional[Any] = Field(default=None, description="Metadata")
    metadata: Optional[Any] = Field(default=None, description="Metadata")
    created_at: Optional[datetime] = None
    updated_at: datetime
    __properties: ClassVar[List[str]] = ["id", "name", "institution_type", "location", "website", "accreditation", "established_year", "data", "metadata", "created_at", "updated_at"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Institution from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "id",
            "updated_at",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if location (nullable) is None
        # and model_fields_set contains the field
        if self.location is None and "location" in self.model_fields_set:
            _dict['location'] = None

        # set to None if website (nullable) is None
        # and model_fields_set contains the field
        if self.website is None and "website" in self.model_fields_set:
            _dict['website'] = None

        # set to None if accreditation (nullable) is None
        # and model_fields_set contains the field
        if self.accreditation is None and "accreditation" in self.model_fields_set:
            _dict['accreditation'] = None

        # set to None if established_year (nullable) is None
        # and model_fields_set contains the field
        if self.established_year is None and "established_year" in self.model_fields_set:
            _dict['established_year'] = None

        # set to None if data (nullable) is None
        # and model_fields_set contains the field
        if self.data is None and "data" in self.model_fields_set:
            _dict['data'] = None

        # set to None if metadata (nullable) is None
        # and model_fields_set contains the field
        if self.metadata is None and "metadata" in self.model_fields_set:
            _dict['metadata'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Institution from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "institution_type": obj.get("institution_type"),
            "location": obj.get("location"),
            "website": obj.get("website"),
            "accreditation": obj.get("accreditation"),
            "established_year": obj.get("established_year"),
            "data": obj.get("data"),
            "metadata": obj.get("metadata"),
            "created_at": obj.get("created_at"),
            "updated_at": obj.get("updated_at")
        })
        return _obj





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class ProgramLicenseAssignmentCreate(BaseModel):
    """
    Request serializer for ProgramLicenseAssignmentView POST endpoint.  This serializer validates the request data for creating or updating a program license assignment. Either user_id or email must be provided to identify the user to assign the license to.  Fields:     license_id: The ID of the program license to assign     user_id: The user ID to assign the license to (required if email not provided)     username: The username to assign the license to (alternative to user_id)     email: The email to assign the license to (required if user_id not provided)     platform_key: The unique identifier for the platform (for permission validation)     platform_org: The organization identifier for the platform (for permission validation)     active: Whether the assignment should be active     fulfilled: Whether the assignment should be marked as fulfilled     direct: Whether the assignment is being directly assigned to the user     redirect_to: URL to redirect to after fulfillment     metadata: Additional metadata for the assignment  Notes:     - If both user_id and email are provided, user_id takes precedence     - If the user doesn't exist but email is provided, an email-only assignment will be created     - The license must have available seats for the assignment to succeed
    """ # noqa: E501
    license_id: StrictInt = Field(description="The ID of the program license to assign")
    user_id: Optional[StrictInt] = Field(default=None, description="The user ID to assign the license to (required if email not provided)")
    username: Optional[StrictStr] = Field(default=None, description="The username to assign the license to (alternative to user_id)")
    email: Optional[StrictStr] = Field(default=None, description="The email to assign the license to (required if user_id not provided)")
    platform_key: Optional[StrictStr] = Field(default=None, description="The unique identifier for the platform (for permission validation)")
    platform_org: Optional[StrictStr] = Field(default=None, description="The organization identifier for the platform (for permission validation)")
    active: Optional[StrictBool] = Field(default=True, description="Whether the assignment should be active")
    fulfilled: Optional[StrictBool] = Field(default=False, description="Whether the assignment should be marked as fulfilled")
    direct: Optional[StrictBool] = Field(default=True, description="Whether the assignment is being directly assigned to the user")
    redirect_to: Optional[StrictStr] = Field(default=None, description="URL to redirect to after fulfillment")
    metadata: Optional[Dict[str, Any]] = Field(default=None, description="Additional metadata for the assignment")
    __properties: ClassVar[List[str]] = ["license_id", "user_id", "username", "email", "platform_key", "platform_org", "active", "fulfilled", "direct", "redirect_to", "metadata"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ProgramLicenseAssignmentCreate from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if redirect_to (nullable) is None
        # and model_fields_set contains the field
        if self.redirect_to is None and "redirect_to" in self.model_fields_set:
            _dict['redirect_to'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ProgramLicenseAssignmentCreate from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "license_id": obj.get("license_id"),
            "user_id": obj.get("user_id"),
            "username": obj.get("username"),
            "email": obj.get("email"),
            "platform_key": obj.get("platform_key"),
            "platform_org": obj.get("platform_org"),
            "active": obj.get("active") if obj.get("active") is not None else True,
            "fulfilled": obj.get("fulfilled") if obj.get("fulfilled") is not None else False,
            "direct": obj.get("direct") if obj.get("direct") is not None else True,
            "redirect_to": obj.get("redirect_to"),
            "metadata": obj.get("metadata")
        })
        return _obj





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class ProgramLicenseAssignmentDetail(BaseModel):
    """
    Response serializer for program license assignment details.  This serializer represents a program license assignment with all its attributes, including user information, license details, and assignment status.  Fields:     id: The unique identifier for the assignment     user_id: The ID of the user assigned the license (may be null for email-only assignments)     username: The username of the user assigned the license (may be null for email-only assignments)     name: The full name of the user assigned the license (may be null for email-only assignments)     email: The email address of the user assigned the license (may be null for user-only assignments)     active: Whether the assignment is active and valid     fulfilled: Whether the assignment has been processed/fulfilled     direct: Whether the assignment was directly assigned to the user (vs. via a group)     redirect_to: URL to redirect to after fulfillment     metadata: Additional metadata for the assignment     created: When the assignment was created     modified: When the assignment was last modified     license_id: The ID of the program license     license_name: The name of the program license     program_key: The program key associated with the license
    """ # noqa: E501
    id: StrictInt = Field(description="The unique identifier for the assignment")
    user_id: Optional[StrictInt] = Field(description="The ID of the user assigned the license")
    username: Optional[StrictStr] = Field(description="The username of the user assigned the license")
    name: Optional[StrictStr] = Field(description="The full name of the user assigned the license")
    email: Optional[StrictStr] = Field(description="The email address of the user assigned the license")
    active: StrictBool = Field(description="Whether the assignment is active and valid")
    fulfilled: StrictBool = Field(description="Whether the assignment has been processed/fulfilled")
    direct: Optional[StrictBool] = Field(default=None, description="Whether the assignment was directly assigned to the user (vs. via a group)")
    redirect_to: Optional[StrictStr] = Field(default=None, description="URL to redirect to after fulfillment")
    metadata: Optional[Dict[str, Any]] = Field(description="Additional metadata for the assignment")
    created: Optional[datetime] = Field(default=None, description="When the assignment was created")
    modified: Optional[datetime] = Field(default=None, description="When the assignment was last modified")
    license_id: StrictInt = Field(description="The ID of the program license")
    license_name: StrictStr = Field(description="The name of the program license")
    program_key: StrictStr = Field(description="The program key associated with the license")
    __properties: ClassVar[List[str]] = ["id", "user_id", "username", "name", "email", "active", "fulfilled", "direct", "redirect_to", "metadata", "created", "modified", "license_id", "license_name", "program_key"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ProgramLicenseAssignmentDetail from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if user_id (nullable) is None
        # and model_fields_set contains the field
        if self.user_id is None and "user_id" in self.model_fields_set:
            _dict['user_id'] = None

        # set to None if username (nullable) is None
        # and model_fields_set contains the field
        if self.username is None and "username" in self.model_fields_set:
            _dict['username'] = None

        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if email (nullable) is None
        # and model_fields_set contains the field
        if self.email is None and "email" in self.model_fields_set:
            _dict['email'] = None

        # set to None if metadata (nullable) is None
        # and model_fields_set contains the field
        if self.metadata is None and "metadata" in self.model_fields_set:
            _dict['metadata'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ProgramLicenseAssignmentDetail from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "user_id": obj.get("user_id"),
            "username": obj.get("username"),
            "name": obj.get("name"),
            "email": obj.get("email"),
            "active": obj.get("active"),
            "fulfilled": obj.get("fulfilled"),
            "direct": obj.get("direct"),
            "redirect_to": obj.get("redirect_to"),
            "metadata": obj.get("metadata"),
            "created": obj.get("created"),
            "modified": obj.get("modified"),
            "license_id": obj.get("license_id"),
            "license_name": obj.get("license_name"),
            "program_key": obj.get("program_key")
        })
        return _obj





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.question_request import QuestionRequest

class TestQuestionRequest(unittest.TestCase):
    """QuestionRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> QuestionRequest:
        """Test QuestionRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `QuestionRequest`
        """
        model = QuestionRequest()
        if include_optional:
            return QuestionRequest(
                username = '',
                initial_questions = [
                    iblai.models.input_question.InputQuestion(
                        text = '', 
                        difficulty_level = 1, 
                        possible_answers = [
                            iblai.models.intial_question_answer.IntialQuestionAnswer(
                                text = '', )
                            ], )
                    ],
                question_count = 56,
                subject = ''
            )
        else:
            return QuestionRequest(
                username = '',
                initial_questions = [
                    iblai.models.input_question.InputQuestion(
                        text = '', 
                        difficulty_level = 1, 
                        possible_answers = [
                            iblai.models.intial_question_answer.IntialQuestionAnswer(
                                text = '', )
                            ], )
                    ],
                subject = '',
        )
        """

    def testQuestionRequest(self):
        """Test QuestionRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from iblai.models.rbac_base_role import RbacBaseRole
from iblai.models.rbac_platform import RbacPlatform
from iblai.models.rbac_policy_group import RbacPolicyGroup
from iblai.models.rbac_user import RbacUser
from typing import Optional, Set
from typing_extensions import Self

class RbacPolicy(BaseModel):
    """
    Serializer for policies.
    """ # noqa: E501
    id: StrictInt
    role: RbacBaseRole = Field(description="Role information (read-only)")
    platform: RbacPlatform = Field(description="Platform information (read-only)")
    resources: List[StrictStr] = Field(description="List of resource paths this policy grants access to (e.g., ['/platforms/1/mentors', '/platforms/1/mentors/settings'])")
    users: List[RbacUser]
    groups: List[RbacPolicyGroup]
    role_id: StrictInt = Field(description="ID of the role this policy applies to")
    platform_key: StrictStr = Field(description="Platform key where this policy applies")
    users_to_add: Optional[List[StrictInt]] = Field(default=None, description="List of user IDs to add to this Policy")
    users_to_remove: Optional[List[StrictInt]] = Field(default=None, description="List of user IDs to remove from this Policy")
    groups_to_add: Optional[List[StrictInt]] = Field(default=None, description="List of group IDs to add to this Policy")
    groups_to_remove: Optional[List[StrictInt]] = Field(default=None, description="List of group IDs to remove from this Policy")
    __properties: ClassVar[List[str]] = ["id", "role", "platform", "resources", "users", "groups", "role_id", "platform_key", "users_to_add", "users_to_remove", "groups_to_add", "groups_to_remove"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of RbacPolicy from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "id",
            "role",
            "platform",
            "users",
            "groups",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of role
        if self.role:
            _dict['role'] = self.role.to_dict()
        # override the default output from pydantic by calling `to_dict()` of platform
        if self.platform:
            _dict['platform'] = self.platform.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in users (list)
        _items = []
        if self.users:
            for _item in self.users:
                if _item:
                    _items.append(_item.to_dict())
            _dict['users'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in groups (list)
        _items = []
        if self.groups:
            for _item in self.groups:
                if _item:
                    _items.append(_item.to_dict())
            _dict['groups'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of RbacPolicy from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "role": RbacBaseRole.from_dict(obj["role"]) if obj.get("role") is not None else None,
            "platform": RbacPlatform.from_dict(obj["platform"]) if obj.get("platform") is not None else None,
            "resources": obj.get("resources"),
            "users": [RbacUser.from_dict(_item) for _item in obj["users"]] if obj.get("users") is not None else None,
            "groups": [RbacPolicyGroup.from_dict(_item) for _item in obj["groups"]] if obj.get("groups") is not None else None,
            "role_id": obj.get("role_id"),
            "platform_key": obj.get("platform_key"),
            "users_to_add": obj.get("users_to_add"),
            "users_to_remove": obj.get("users_to_remove"),
            "groups_to_add": obj.get("groups_to_add"),
            "groups_to_remove": obj.get("groups_to_remove")
        })
        return _obj





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class UserLicenseUpdate(BaseModel):
    """
    Request serializer for UserLicenseUpdateView POST endpoint
    """ # noqa: E501
    license_id: Optional[StrictInt] = Field(default=None, description="The ID of the license to update (required if external_id not provided)")
    external_id: Optional[StrictStr] = Field(default=None, description="External identifier of the license to update (required if license_id not provided)")
    platform_key: Optional[StrictStr] = Field(default=None, description="The platform key (not updatable)")
    platform_org: Optional[StrictStr] = Field(default=None, description="The platform organization (not updatable)")
    name: Optional[StrictStr] = Field(default=None, description="Updated display name for the license")
    count: Optional[StrictInt] = Field(default=None, description="Updated number of seats purchased")
    started: Optional[datetime] = Field(default=None, description="Updated date when license should begin")
    expired: Optional[datetime] = Field(default=None, description="Updated date when license should expire")
    active: Optional[StrictBool] = Field(default=None, description="Updated active status")
    metadata: Optional[Dict[str, Any]] = Field(default=None, description="Updated additional license metadata")
    enrollment_config: Optional[Dict[str, Any]] = Field(default=None, description="Updated enrollment configuration")
    source: Optional[StrictStr] = Field(default=None, description="Updated source identifier")
    transaction_id: Optional[StrictStr] = Field(default=None, description="Transaction identifier for tracking")
    change_type: Optional[StrictStr] = Field(default='update', description="Type of change being made")
    __properties: ClassVar[List[str]] = ["license_id", "external_id", "platform_key", "platform_org", "name", "count", "started", "expired", "active", "metadata", "enrollment_config", "source", "transaction_id", "change_type"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UserLicenseUpdate from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if expired (nullable) is None
        # and model_fields_set contains the field
        if self.expired is None and "expired" in self.model_fields_set:
            _dict['expired'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UserLicenseUpdate from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "license_id": obj.get("license_id"),
            "external_id": obj.get("external_id"),
            "platform_key": obj.get("platform_key"),
            "platform_org": obj.get("platform_org"),
            "name": obj.get("name"),
            "count": obj.get("count"),
            "started": obj.get("started"),
            "expired": obj.get("expired"),
            "active": obj.get("active"),
            "metadata": obj.get("metadata"),
            "enrollment_config": obj.get("enrollment_config"),
            "source": obj.get("source"),
            "transaction_id": obj.get("transaction_id"),
            "change_type": obj.get("change_type") if obj.get("change_type") is not None else 'update'
        })
        return _obj





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.perlearner_user_list import PerlearnerUserList

class TestPerlearnerUserList(unittest.TestCase):
    """PerlearnerUserList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PerlearnerUserList:
        """Test PerlearnerUserList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PerlearnerUserList`
        """
        model = PerlearnerUserList()
        if include_optional:
            return PerlearnerUserList(
                data = [
                    iblai.models.perlearner_user_list_data.PerlearnerUserListData(
                        username = '', 
                        full_name = '', 
                        enrollments = 56, 
                        completions = 56, 
                        last_active = '', 
                        time_spent = '', 
                        engagement_index = 1.337, 
                        performance_index = 1.337, )
                    ],
                pagination = iblai.models.pagination.Pagination(
                    total_items = 56, 
                    current_page = 56, 
                    per_page = 56, 
                    total_pages = 56, )
            )
        else:
            return PerlearnerUserList(
                pagination = iblai.models.pagination.Pagination(
                    total_items = 56, 
                    current_page = 56, 
                    per_page = 56, 
                    total_pages = 56, ),
        )
        """

    def testPerlearnerUserList(self):
        """Test PerlearnerUserList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.question_response import QuestionResponse

class TestQuestionResponse(unittest.TestCase):
    """QuestionResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> QuestionResponse:
        """Test QuestionResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `QuestionResponse`
        """
        model = QuestionResponse()
        if include_optional:
            return QuestionResponse(
                questions = [
                    iblai.models.llm_question.LLMQuestion(
                        text = '', 
                        difficulty_level = 1, 
                        options = [
                            iblai.models.answer.Answer(
                                text = '', 
                                is_correct = True, )
                            ], )
                    ]
            )
        else:
            return QuestionResponse(
                questions = [
                    iblai.models.llm_question.LLMQuestion(
                        text = '', 
                        difficulty_level = 1, 
                        options = [
                            iblai.models.answer.Answer(
                                text = '', 
                                is_correct = True, )
                            ], )
                    ],
        )
        """

    def testQuestionResponse(self):
        """Test QuestionResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from iblai.models.notification_source import NotificationSource
from iblai.models.notification_template_data import NotificationTemplateData
from typing import Optional, Set
from typing_extensions import Self

class NotificationPreview(BaseModel):
    """
    Request serializer for notification preview
    """ # noqa: E501
    template_id: Optional[StrictStr] = Field(default=None, description="Use a predefined template in the system")
    template_data: Optional[NotificationTemplateData] = Field(default=None, description="Specify this to send a new custom message without using a predefined template")
    channels: List[StrictInt] = Field(description="Specify the channel ids to send notifications to.")
    sources: List[NotificationSource] = Field(description="Specify the sources to send notifications to")
    context: Optional[Dict[str, Any]] = Field(default=None, description="Specify the context that would be available in the message text")
    process_on: Optional[datetime] = Field(default=None, description="(ISO datetime) Specify the date and time of processing this notification. Note, notifications are sent hourly and only scheduled messages prior to the beginning of the hour would be sent")
    __properties: ClassVar[List[str]] = ["template_id", "template_data", "channels", "sources", "context", "process_on"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of NotificationPreview from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of template_data
        if self.template_data:
            _dict['template_data'] = self.template_data.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in sources (list)
        _items = []
        if self.sources:
            for _item in self.sources:
                if _item:
                    _items.append(_item.to_dict())
            _dict['sources'] = _items
        # set to None if template_id (nullable) is None
        # and model_fields_set contains the field
        if self.template_id is None and "template_id" in self.model_fields_set:
            _dict['template_id'] = None

        # set to None if template_data (nullable) is None
        # and model_fields_set contains the field
        if self.template_data is None and "template_data" in self.model_fields_set:
            _dict['template_data'] = None

        # set to None if process_on (nullable) is None
        # and model_fields_set contains the field
        if self.process_on is None and "process_on" in self.model_fields_set:
            _dict['process_on'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of NotificationPreview from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "template_id": obj.get("template_id"),
            "template_data": NotificationTemplateData.from_dict(obj["template_data"]) if obj.get("template_data") is not None else None,
            "channels": obj.get("channels"),
            "sources": [NotificationSource.from_dict(_item) for _item in obj["sources"]] if obj.get("sources") is not None else None,
            "context": obj.get("context"),
            "process_on": obj.get("process_on")
        })
        return _obj





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.api.credentials_api import CredentialsApi


class TestCredentialsApi(unittest.TestCase):
    """CredentialsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CredentialsApi()

    def tearDown(self) -> None:
        pass

    def test_credentials_orgs_users_assertions_bulk_create(self) -> None:
        """Test case for credentials_orgs_users_assertions_bulk_create

        """
        pass

    def test_credentials_orgs_users_assertions_create(self) -> None:
        """Test case for credentials_orgs_users_assertions_create

        """
        pass

    def test_credentials_orgs_users_assertions_over_time_retrieve(self) -> None:
        """Test case for credentials_orgs_users_assertions_over_time_retrieve

        """
        pass

    def test_credentials_orgs_users_assertions_retrieve(self) -> None:
        """Test case for credentials_orgs_users_assertions_retrieve

        """
        pass

    def test_credentials_orgs_users_assertions_retrieve2(self) -> None:
        """Test case for credentials_orgs_users_assertions_retrieve2

        """
        pass

    def test_credentials_orgs_users_assertions_retrieve3(self) -> None:
        """Test case for credentials_orgs_users_assertions_retrieve3

        """
        pass

    def test_credentials_orgs_users_assertions_update(self) -> None:
        """Test case for credentials_orgs_users_assertions_update

        """
        pass

    def test_credentials_orgs_users_course_assertions_over_time_retrieve(self) -> None:
        """Test case for credentials_orgs_users_course_assertions_over_time_retrieve

        """
        pass

    def test_credentials_orgs_users_course_credentials_list(self) -> None:
        """Test case for credentials_orgs_users_course_credentials_list

        """
        pass

    def test_credentials_orgs_users_create(self) -> None:
        """Test case for credentials_orgs_users_create

        """
        pass

    def test_credentials_orgs_users_credentials_over_time_retrieve(self) -> None:
        """Test case for credentials_orgs_users_credentials_over_time_retrieve

        """
        pass

    def test_credentials_orgs_users_destroy(self) -> None:
        """Test case for credentials_orgs_users_destroy

        """
        pass

    def test_credentials_orgs_users_issuers_authority_create(self) -> None:
        """Test case for credentials_orgs_users_issuers_authority_create

        """
        pass

    def test_credentials_orgs_users_issuers_create(self) -> None:
        """Test case for credentials_orgs_users_issuers_create

        """
        pass

    def test_credentials_orgs_users_issuers_destroy(self) -> None:
        """Test case for credentials_orgs_users_issuers_destroy

        """
        pass

    def test_credentials_orgs_users_issuers_retrieve(self) -> None:
        """Test case for credentials_orgs_users_issuers_retrieve

        """
        pass

    def test_credentials_orgs_users_issuers_retrieve2(self) -> None:
        """Test case for credentials_orgs_users_issuers_retrieve2

        """
        pass

    def test_credentials_orgs_users_issuers_update(self) -> None:
        """Test case for credentials_orgs_users_issuers_update

        """
        pass

    def test_credentials_orgs_users_retrieve(self) -> None:
        """Test case for credentials_orgs_users_retrieve

        """
        pass

    def test_credentials_orgs_users_retrieve2(self) -> None:
        """Test case for credentials_orgs_users_retrieve2

        """
        pass

    def test_credentials_orgs_users_update(self) -> None:
        """Test case for credentials_orgs_users_update

        """
        pass

    def test_credentials_public_assertions_retrieve(self) -> None:
        """Test case for credentials_public_assertions_retrieve

        """
        pass


if __name__ == '__main__':
    unittest.main()
